#
# spec file for package terminator
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global __requires_exclude typelib\\(Gnome\\)
Name:           terminator
Version:        1.91
Release:        3.1
Summary:        Store and run multiple GNOME terminals in one window
License:        GPL-2.0-only
Group:          System/X11/Terminals
URL:            https://gnometerminator.blogspot.cz/p/introduction.html
Source0:        https://launchpad.net/%{name}/gtk3/%{version}/+download/%{name}-%{version}.tar.gz
Patch0:         terminator-desktop.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  python-devel
BuildRequires:  update-desktop-files
Requires:       python-cairo
Requires:       python-gobject
Requires:       python-gobject-Gdk
Requires:       python-psutil
Requires(post): hicolor-icon-theme
Requires(postun): hicolor-icon-theme
Recommends:     %{name}-lang
BuildArch:      noarch

%description
Multiple GNOME terminals in one window.  This is a project to produce
an efficient way of filling a large area of screen space with
terminals. This is done by splitting the window into a resizeable
grid of terminals. As such, you can  produce a very flexible
arrangements of terminals for different tasks.

%lang_package

%prep
%setup -q
%patch0

# remove pointless shebangs
sed -i '/#! \?\/usr.*/d' terminatorlib/*.py

%build
python setup.py build

%install
python setup.py install --root=%{buildroot} --prefix=%{_prefix}

rm -f %{buildroot}/%{_datadir}/icons/hicolor/icon-theme.cache
rm -f %{buildroot}/%{_datadir}/applications/%{name}.desktop
rm -rf %{buildroot}%{_datadir}/doc/terminator/apidoc/.buildinfo
rm -rf %{buildroot}%{_datadir}/doc/terminator/html/.buildinfo

desktop-file-install --vendor="" --dir=%{buildroot}%{_datadir}/applications data/%{name}.desktop
%suse_update_desktop_file %{name}

%fdupes %{buildroot}
%find_lang %{name}

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%license COPYING
%doc ChangeLog README
%dir %{_datadir}/icons/HighContrast
%dir %{_datadir}/icons/HighContrast/16x16
%dir %{_datadir}/icons/HighContrast/16x16/actions
%dir %{_datadir}/icons/HighContrast/16x16/apps
%dir %{_datadir}/icons/HighContrast/16x16/status
%dir %{_datadir}/icons/HighContrast/22x22
%dir %{_datadir}/icons/HighContrast/22x22/apps
%dir %{_datadir}/icons/HighContrast/24x24
%dir %{_datadir}/icons/HighContrast/24x24/apps
%dir %{_datadir}/icons/HighContrast/32x32
%dir %{_datadir}/icons/HighContrast/32x32/apps
%dir %{_datadir}/icons/HighContrast/48x48
%dir %{_datadir}/icons/HighContrast/48x48/apps
%dir %{_datadir}/icons/HighContrast/scalable
%dir %{_datadir}/icons/HighContrast/scalable/apps
%{_bindir}/%{name}*
%{_bindir}/remotinator
%{_mandir}/man1/%{name}.*
%{_mandir}/man5/%{name}_config.*
%{python_sitelib}/*
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/%{name}*.png
%{_datadir}/icons/hicolor/*/*/%{name}*.svg
%{_datadir}/icons/HighContrast/*/*/%{name}*.png
%{_datadir}/icons/HighContrast/*/*/%{name}*.svg
%{_datadir}/icons/hicolor/16x16/status/terminal-bell.png
%{_datadir}/icons/HighContrast/16x16/status/terminal-bell.png
%{_datadir}/pixmaps/%{name}.png
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/terminatorlib
%dir %{_datadir}/%{name}/terminatorlib/themes
%dir %{_datadir}/%{name}/terminatorlib/themes/Adwaita
%dir %{_datadir}/%{name}/terminatorlib/themes/Adwaita/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Adwaita/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/Ambiance
%dir %{_datadir}/%{name}/terminatorlib/themes/Ambiance/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Ambiance/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/Breeze
%dir %{_datadir}/%{name}/terminatorlib/themes/Breeze/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Breeze/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/HighContrast
%dir %{_datadir}/%{name}/terminatorlib/themes/HighContrast/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/HighContrast/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/Radiance
%dir %{_datadir}/%{name}/terminatorlib/themes/Radiance/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Radiance/gtk-3.0/apps
%dir %{_datadir}/%{name}/terminatorlib/themes/Raleigh
%dir %{_datadir}/%{name}/terminatorlib/themes/Raleigh/gtk-3.0
%dir %{_datadir}/%{name}/terminatorlib/themes/Raleigh/gtk-3.0/apps
%{_datadir}/%{name}/terminatorlib/themes/Adwaita/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/Ambiance/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/Ambiance/gtk-3.0/apps/terminator_styling.css
%{_datadir}/%{name}/terminatorlib/themes/Breeze/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/HighContrast/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/Radiance/gtk-3.0/apps/terminator.css
%{_datadir}/%{name}/terminatorlib/themes/Radiance/gtk-3.0/apps/terminator_styling.css
%{_datadir}/%{name}/terminatorlib/themes/Raleigh/gtk-3.0/apps/terminator.css

%files lang -f %{name}.lang

%changelog
* Mon Aug 27 2018 tchvatal@suse.com
- Add dependency on python-cairo wrt bug#1105830
* Wed Apr 18 2018 tchvatal@suse.com
- Add direct dependency on python-gobject-Gdk without it the pkg
  fails on not finding the screen
* Fri Mar 23 2018 tchvatal@suse.com
- Fix URL and format with spec-cleaner
* Wed Nov 29 2017 scabrero@suse.com
- Version update to 1.91 release:
  * No significant new features. Just minor enhancements and lots
    of fixes.
* Wed Feb  8 2017 dimstar@opensuse.org
- Filter out auto-detected typelib(Gnome) dependency. This does not
  exist on recent GNOME desktops and terminator's code can handle
  it as an optional feature (boo#1024260).
* Mon Feb  6 2017 dimstar@opensuse.org
- Fix dependency chain (auto-detection, boo#1023712):
  + Add gobject-introspection BuildRequires
  + Drop typlib-1_0-Keybinder-3_0 Requires: it is being
    auto-detected.
  + Drop vte Requires: this is provided by the library, but the
    terminator code does not interact with it directly. It uses
    the g-i bindings only.
  + Drop python-vte Requires: since the app was ported to be
    gobject introspected, the legacy python-vte is no longer
    needed.
* Tue Jan 24 2017 tchvatal@suse.com
- Version update to 1.90 release:
  * Switch to gtk3 RC release
* Tue Jan 24 2017 tchvatal@suse.com
- Version update to 1.0:
  * Few last fixes from 0.98 marking last release using gtk2
- Drop merged patch:
  * 0001-terminator-fix-RHBZ#1268289.patch
- Drop support for SLE-11
* Sat Feb 20 2016 tchvatal@suse.com
- Version update to 0.98:
  * Run the macro scriptlets for icons/desktop files
  * Adjust filelist for the current state
  * Fix few tiny rpmlint warnings
- Add patch:
  * 0001-terminator-fix-RHBZ#1268289.patch
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Tue Sep 24 2013 rbrownccb@opensuse.org
- update to 0.97
- bug fixes incl. bnc#842059
- for details see package changelog
* Thu Mar 15 2012 saschpe@suse.de
- Some more spec cleanup
* Thu Jan 26 2012 lijewski.stefan@zabka.pl
- spec cleanup
- split languge package
- add python-keybinder recomends
* Fri Nov 18 2011 lijewski.stefan@gmail.com
- fix build on 12.1
* Thu Nov 17 2011 lijewski.stefan@gmail.com
- update to 0.96 - for details see package changelog
* Tue Apr  5 2011 lijewski.stefan@gmail.com
- fix openSUSE:Factory build missing lang files
* Mon Mar 14 2011 Stefan Lijewski <lijewski.stefan@gmail.com> 0.95
- Fix dependencies bug (bug id 679206)
* Fri Mar 11 2011 Stefan Lijewski <lijewski.stefan@gmail.com> 0.95
- Fix build bug about directories in openSuSE 11.4
* Tue Sep 21 2010 Stefan Lijewski <lijewski.stefan@gmail.com> 0.95
-initial changelog for openSuse
* Wed Mar 31 2010 Chris Jones <cmsj@tenshu.net> 0.91-1
- Update to fix some stupid release bugs in 0.90.
    Note that this specfile is untested.
* Tue Jan  5 2010 Chris Jones <cmsj@tenshu.net> 0.90-1
- Attempt to update for 0.90 pre-release.
    Note that this specfile is untested.
* Thu Jan 15 2009 Chris Jones <cmsj@tenshu.net> 0.12-1
- Remove patch application since this isn't a fedora build.
    Note that this specfile is untested.
* Mon Dec  8 2008 Ian Weller <ianweller@gmail.com> 0.11-3
- Patch version in terminatorlib/verison.py to the one we think it is
- Fix License tag
- Update post and postun scripts with one line
* Mon Dec  1 2008 Ian Weller <ianweller@gmail.com> 0.11-2
- Add BuildRequires: gettext
- Fix installation of .desktop file
- terminator-0.11-desktop.patch:
    Remove useless things
    Move to same category as gnome-terminal
- Uses spaces instead of tabs in the specfile because I can't stand tabs
* Mon Dec  1 2008 Ian Weller <ianweller@gmail.com> 0.11-1
- Update upstream
- Fix description to something useful
- Fix group
- Fix some specfile oddities
- Complete/restandardize file list
- Get rid of she-bangs in python_sitelib
  * Sat Sep 13 2008 - Max Spevack <mspevack AT redhat DOT com> 0.10
- New upstream release.
- Tried to make sure the spec file matches guidelines on Fedora wiki.
  * Fri Jul 08 2008 - chantra AatT rpm-based DdOoTt org 0.9.fc9.rb
- New upstream release
  * Sat May 17 2008 - chantra AatT rpm-based DdOoTt org 0.8.1.fc9.rb
- Initial release for Fedora 9.
